@@ -39,7 +39,7 @@ def init(creds_path_, sheet_name_, worksheet_idx_=0):
     else:
         monitor_health(worksheet, sno)
 
-def log_data(offset=0, **kwargs):
+def log_data(offset=0, increment_cols=True, **kwargs):
     global sno 
     global column_idx
     global worksheet 
@@ -57,4 +57,6 @@ def log_data(offset=0, **kwargs):
         df = pd.DataFrame(kwargs)
 
     worksheet.set_dataframe(df, (sno + 1, column_idx + offset), copy_head=False)
-    column_idx += len(kwargs) + offset
\ No newline at end of file
+    
+    if increment_cols:
+        column_idx += len(kwargs) + offset
\ No newline at end of file
